//-----------------------------------------------------------------------------
// File: spritemulti.fx
//
// Description:
//
// Copyright(c) 2001 - 2007 Derek Long. All rights reserved
//-----------------------------------------------------------------------------



float4x4 WorldViewProjection  : WORLDVIEWPROJECTION;

texture g_Texture0;    
texture g_Texture1;   


sampler Sampler1 = sampler_state
{
	Texture   = (g_Texture0);
	AddressU  = CLAMP;        
    AddressV  = CLAMP;
    AddressW  = CLAMP;
    MipFilter = NONE;
    MinFilter = LINEAR;
    MagFilter = LINEAR;	
};

sampler Sampler2 = sampler_state
{
	Texture   = (g_Texture1);
	AddressU  = CLAMP;        
    AddressV  = CLAMP;
    AddressW  = CLAMP;
    MipFilter = NONE;
    MinFilter = LINEAR;
    MagFilter = LINEAR;	
};


//-----------------------------------------------------------------------------
// Vertex Shader: VertScene
// Desc: Process vertex for scene
//-----------------------------------------------------------------------------
void VertScene( float4 iPos : POSITION,
				float4 iColor : COLOR0,                
                float2 iTex : TEXCOORD0,
                out float4 oPos : POSITION,
                out float4 oColor : COLOR0,
                out float2 oTex : TEXCOORD0)
{	
	oPos = mul(iPos, WorldViewProjection);    
    oColor = iColor;
    oTex = iTex;
}




//-----------------------------------------------------------------------------
// Pixel Shader: PixScene
// Desc: Process pixel (do per-pixel lighting) for enabled scene
//-----------------------------------------------------------------------------
float4 PixScene( float4 Color : COLOR0,
				 float2 Tex : TEXCOORD0) : COLOR
{
    float4 FinalColor,Texture1,Texture2;
    
    
	Texture1 = tex2D( Sampler1, Tex );
	Texture2 = tex2D( Sampler2, Tex );
	FinalColor = Color * Texture1 * Texture2;

    return FinalColor;
}

technique DefaultOld
{
    pass P0
    {
		Lighting         = FALSE;
        SpecularEnable   = FALSE;
		ZENABLE          = FALSE;
		ZWriteEnable     = FALSE;
		CULLMODE         = NONE;
		ALPHABLENDENABLE = TRUE;
		ALPHATESTENABLE  = FALSE;
		SrcBlend         = SRCALPHA;
        DestBlend        = INVSRCALPHA;		
		FOGENABLE        = FALSE;
		
								
								   
		// shaders		
		VertexShader = compile vs_2_0 VertScene();
        PixelShader = compile ps_2_0 PixScene();       
    }
}

/*
technique Default
{
    pass P0
    {
		ZENABLE = FALSE;
		ALPHABLENDENABLE = TRUE;
		ALPHATESTENABLE = FALSE;
		
								
								   
		// shaders		
		VertexShader = compile vs_3_0 VertScene();
        PixelShader = compile ps_3_0 PixScene();       
    }
}*/



/*
technique Default
{
    pass P0
    {
		LIGHTING = FALSE;			
		SPECULARENABLE = FALSE;		
		ALPHABLENDENABLE = TRUE;	
		SRCBLEND         = SRCALPHA;		
		DESTBLEND        = INVSRCALPHA;	
		ALPHATESTENABLE  = TRUE;		
		ALPHAREF         = 0x01;			
		ALPHAFUNC        = GREATEREQUAL;	
		FILLMODE = SOLID;			
		CULLMODE = NONE;			
		ZENABLE = FALSE;			
		FOGENABLE = FALSE;			
								
								
		// samplers				
		Sampler[0] = (Sampler);	
								
		// texture stages			
		ColorOp[0]   = MODULATE;  
		ColorArg1[0] = TEXTURE;	
		ColorArg2[0] = DIFFUSE;	
		AlphaOp[0]   = MODULATE;	
		AlphaArg1[0] = TEXTURE;	
		AlphaArg2[0] = DIFFUSE;	
								
		ColorOp[1]   = DISABLE;   
		AlphaOp[1]   = DISABLE;   
							   
		// shaders				   
		VertexShader = NULL;      
		PixelShader  = NULL;      
		
       
    }
}*/

